const path = require('path');
const webpack = require('webpack');
const autoprefixer = require('autoprefixer');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

module.exports = {
	context: __dirname,
	entry: ['./src/app.js'],
	output: {
		path: path.join(__dirname, 'build'),
		filename: 'react-toolbox.js',
		publicPath: '/'
	},
	resolve: {
		extensions: [
			'', '.scss', '.css', '.js', '.json'
		],
		modulesDirectories: [
			'node_modules',
			path.resolve(__dirname, './node_modules')
		]
	},
	module: {
		loaders: [
			{
				test: /(\.js|\.jsx)$/,
				exclude: /(node_modules)/,
				loader: 'babel',
				query: {
					presets: ['es2015', 'stage-1', 'react']
				}
			}, {
				test: /(\.scss|\.css)$/,
				loader: ExtractTextPlugin.extract('style', 'css?sourceMap&modules&importLoaders=1&localIdentName=[name]__[local]___[hash:bas' +
						'e64:5]!postcss!sass?sourceMap')
			}
		]
	},
	postcss: [autoprefixer],
	sassLoader: {},
	plugins: [
		new ExtractTextPlugin('react-toolbox.css', {allChunks: true}),
		new webpack.NoErrorsPlugin(),
		new webpack.DefinePlugin({'process.env.NODE_ENV': JSON.stringify('development')})
	]
};
